#!/bin/bash

SAMPLING_FREQ=24000

CONTACT_MATERIAL="1.5% (w/v) neurobiotin (Vector Laboratories, Burlingame, CA,USA) and 2% (w/v) NaCl"

target_folder=`pwd`
target_folder=$target_folder/..
source_folder=$target_folder/sourcedata

participants_file=$target_folder/participants.tsv
echo -e "participant_id\tspecies\tspecies_RRID\tstrain\tsex" > $participants_file

samples_file=$target_folder/samples.tsv
echo -e "sample_id\tparticipant_id\tsample_type" > $samples_file

subjects=`ls $source_folder | grep sub`

for i_subject in $subjects
do

    echo $i_subject

    process=false

    scan_file=$target_folder/$i_subject/${i_subject}_scans.tsv
    probes_tsv=$target_folder/$i_subject/ephys/${i_subject}_probes.tsv
    contacts_tsv=$target_folder/$i_subject/ephys/${i_subject}_contacts.tsv    

    # TODO keep to help figure out info about each sample
    # cat $source_folder/$i_subject/${i_subject}.csv | grep 'Cellule [ABCDEFGHIJ] à'

    # TODO find a cleaner way to know how many electrodes were used
    # at the moment we grep for any mention of an impedance
    nb_probes=`cat $source_folder/$i_subject/${i_subject}.csv | grep '[0-9] MΩ' | wc -l`
    list_probes=`seq 1 $nb_probes`

    # TODO
    # the acquisition time should hopefully be in the spike 2 header (famous last words)
    date=`cat $source_folder/$i_subject/${i_subject}.csv | grep Date | awk '{split($0, a, ","); print a[2]}' | sed "s@/@-@g"`

    if [ -d "$source_folder/$i_subject/ephys" ];
    then
        process=true

        mkdir -p $target_folder/$i_subject/ephys

        # TODO get the correct acquisition time
        echo -e 'filename\tacq_time' > $scan_file

        # TODO figure out the electrode id
        echo -e "probe_id\ttype\tmaterial" > ${probes_tsv}
        for i_probe in $list_probes
        do
            echo -e "pro${i_probe}\tacute\tglass micropipette electrode" >> ${probes_tsv}
        done        

        echo -e "contact_id\tprobe_id\timpedance\timpedance_unit\tx\ty\tz\txyz_units\tmaterial" > ${contacts_tsv}        

        # Loop through the spike 2 files
        # - update scans.tsv
        # - create a dummy data .nix file
        files=`find $source_folder/$i_subject/ephys/ -name "*.smr" -printf "%f\n"`
        COUNTER=0
        for i_file in $files
        do
 
            basename=`echo ${i_file} | sed "s/ephys.smr//g"`

            nix_file=${basename}ephys.nix
            channels_tsv=$target_folder/$i_subject/ephys/${basename}channels.tsv

            echo -e "ephys/${nix_file}\t${date}T00:00:00" >> $scan_file
            touch $target_folder/$i_subject/ephys/${nix_file}

            # TODO figure out the electrode of each cell
            # extract the actual values for each cell
            imp=12
            x=-0.2
            y=0.2
            z=4.97
            echo -e "con${COUNTER}\tpro1\t${imp}\tMΩ\t${x}\t${y}\t${z}\tmm\t${CONTACT_MATERIAL}" >> ${contacts_tsv}

            # TODO 
            # - figure out the number of channels per file
            # - mircovolt must be in SI
            echo -e "channel_id\tcontact_id\ttype\tunits\tsampling_frequency" > ${channels_tsv}
            echo -e "cha001\tcon${COUNTER}\tNEU\tmicrovolt\t${SAMPLING_FREQ}" >> ${channels_tsv}

            # TODO need unique sample id in the dataset
            sample_id=`echo $basename | awk -F"_" '{print $2}' | awk -F"-" '{print $2}'`
            echo -e "${sample_id}\t${i_subject}\tcell" >> $samples_file

            let COUNTER++
            
        done

    fi




    if [ -d "$source_folder/$i_subject/microscopy" ];
    then
        process=true
        mkdir -p $target_folder/$i_subject/microscopy
    fi    

    # For any type of extra processing that should be done in any case 
    if [ "$process" = true ] ; then
        echo -e "${i_subject}\tRattus norvegicus\tRGD_70508\tSprague Dawley\tmale" >> $participants_file
    fi

done